
C MOVES LIST ISPFRM,LSTFRM TO ISPOUT,LSTOUT.  
C
C       T2  - SCRATCH USED FOR THE LIST.
C    NDSSIZ - THE DISTRIBUTION SIZE FOR THE LIST.
C    NUMDIS - THE NUMBER OF DISTRIBUTIONS IN THE LIST.
C    ICACH1 - THE I/O CACHE TO BE USED FOR THE GETLST OPERATION.
C    ICACH2 - THE I/O CACHE TO BE USED FOR THE PUTLST OPERATION.

      SUBROUTINE MVLIST(Z,NDSSIZ,NUMDIS,LSTFRM,LSTOUT,ISPFRM,
     &                  ISPOUT,ICACH1,ICACH2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION Z(NDSSIZ,NUMDIS)
      CALL GETLST(Z,1,NUMDIS,ICACH1,ISPFRM,LSTFRM)
      CALL PUTLST(Z,1,NUMDIS,ICACH2,ISPOUT,LSTOUT)
      RETURN
      END
